diff src/share/vm/runtime/arguments.hpp @ 2891:75a99b4f1c98

Rebranded C++ part from C1X to Graal.
author Thomas Wuerthinger <thomas@wuerthinger.net>
date Wed, 08 Jun 2011 14:01:51 +0200
parents 0654ee04b214
children 4aa80ca3dbec
line wrap: on
line diff
--- a/src/share/vm/runtime/arguments.hpp	Wed Jun 08 13:40:25 2011 +0200
+++ b/src/share/vm/runtime/arguments.hpp	Wed Jun 08 14:01:51 2011 +0200
@@ -228,9 +228,9 @@
   // an array containing all jvm arguments specified in the command line
   static char** _jvm_args_array;
   static int    _num_jvm_args;
-  // an array containing all c1x arguments specified in the command line
-  static char** _c1x_args_array;
-  static int    _num_c1x_args;
+  // an array containing all graal arguments specified in the command line
+  static char** _graal_args_array;
+  static int    _num_graal_args;
   // string containing all java command (class/jarfile name and app args)
   static char* _java_command;
 
@@ -369,7 +369,7 @@
   // methods to build strings from individual args
   static void build_jvm_args(const char* arg);
   static void build_jvm_flags(const char* arg);
-  static void add_c1x_arg(const char* arg);
+  static void add_graal_arg(const char* arg);
   static void add_string(char*** bldarray, int* count, const char* arg);
   static const char* build_resource_string(char** args, int count);
 
@@ -425,9 +425,9 @@
   // return a char* array containing all options
   static char** jvm_flags_array()          { return _jvm_flags_array; }
   static char** jvm_args_array()           { return _jvm_args_array; }
-  static char** c1x_args_array()           { return _c1x_args_array; }
+  static char** graal_args_array()           { return _graal_args_array; }
   static int num_jvm_flags()               { return _num_jvm_flags; }
-  static int num_c1x_args()               { return _num_c1x_args; }
+  static int num_graal_args()               { return _num_graal_args; }
   static int num_jvm_args()                { return _num_jvm_args; }
   // return the arguments passed to the Java application
   static const char* java_command()        { return _java_command; }